﻿using Syncfusion.SfChart.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace MulitipleChart
{
    public class MultipleChartSample : ContentPage
    {
        ObservableCollection<ChartDataPoint> areaSeriesDatas, splineSeriesDatas, lineSeriesDatas;
        SfChart chart1, chart2;
        StackLayout rootLayout, legendLayout, chartLayout;
        AreaSeries areaSeries;
        SplineSeries splineSeries;
        LineSeries lineSeries;
        LineSeries lineSeries1;
        Color[] customColors;
        Grid grid;
        public MultipleChartSample()
        {
            customColors = new Color[4];
            customColors[0] = Color.FromHex("FF3E563F");
            customColors[1] = Color.FromHex("FF81B564");
            customColors[2] = Color.FromHex("FF473939");
            customColors[3] = Color.FromHex("FF9f5e44");

            grid = new Grid();

            rootLayout = new StackLayout();
            rootLayout.BackgroundColor = Color.White;
            rootLayout.Orientation = StackOrientation.Vertical;
            rootLayout.VerticalOptions = LayoutOptions.FillAndExpand;

            chartLayout = new StackLayout();
            chartLayout.VerticalOptions = LayoutOptions.FillAndExpand;

            legendLayout = new StackLayout();
            legendLayout.Padding = new Thickness(10, 10, 10, 0);
            legendLayout.Orientation = StackOrientation.Horizontal;

            areaSeriesDatas = new ObservableCollection<ChartDataPoint>();
            splineSeriesDatas = new ObservableCollection<ChartDataPoint>();
            lineSeriesDatas = new ObservableCollection<ChartDataPoint>();

            chart1 = new SfChart();
            chart1.Title.Text = "Population Growth";
            chart1.Title.Margin = new Thickness(0, 0, 0, 25);
            chart1.HeightRequest = 350;

            chart2 = new SfChart();
            chart2.Title.Text = "Poverty Level";
            chart2.Title.Margin = new Thickness(0, 0, 0, 50);
            chart2.HeightRequest = 275;

            CategoryAxis catogoryAxis = new CategoryAxis();
            catogoryAxis.LabelStyle.TextColor = Color.Transparent;
            catogoryAxis.MajorTickStyle.StrokeColor = Color.Transparent;
            chart1.PrimaryAxis = catogoryAxis;

            chart1.SecondaryAxis = new NumericalAxis();
            chart1.SecondaryAxis.Title.Text = "Literacy Growth (%)";

            chart2.PrimaryAxis = new CategoryAxis();
            chart2.PrimaryAxis.Title.Text = "Year";
            chart2.SecondaryAxis = new NumericalAxis();
            chart2.SecondaryAxis.Title.Text = "Below Poverty Line";

            areaSeriesDatas.Add(new ChartDataPoint(1, 45));
            areaSeriesDatas.Add(new ChartDataPoint(2, 24));
            areaSeriesDatas.Add(new ChartDataPoint(3, 27));
            areaSeriesDatas.Add(new ChartDataPoint(4, 42));
            areaSeriesDatas.Add(new ChartDataPoint(5, 20));
            areaSeriesDatas.Add(new ChartDataPoint(6, 37));
            areaSeriesDatas.Add(new ChartDataPoint(7, 34));

            splineSeriesDatas.Add(new ChartDataPoint(1, 20));
            splineSeriesDatas.Add(new ChartDataPoint(2, 30));
            splineSeriesDatas.Add(new ChartDataPoint(3, 25));
            splineSeriesDatas.Add(new ChartDataPoint(4, 36));
            splineSeriesDatas.Add(new ChartDataPoint(5, 20));
            splineSeriesDatas.Add(new ChartDataPoint(6, 85));
            splineSeriesDatas.Add(new ChartDataPoint(7, 70));

            lineSeriesDatas.Add(new ChartDataPoint(1, 20));
            lineSeriesDatas.Add(new ChartDataPoint(2, 30));
            lineSeriesDatas.Add(new ChartDataPoint(3, 25));
            lineSeriesDatas.Add(new ChartDataPoint(4, 36));
            lineSeriesDatas.Add(new ChartDataPoint(5, 20));
            lineSeriesDatas.Add(new ChartDataPoint(6, 85));
            lineSeriesDatas.Add(new ChartDataPoint(7, 70));

            areaSeries = new AreaSeries();
            areaSeries.Color = GetColor(0);
            areaSeries.Label = "Population";
            areaSeries.LegendIcon = ChartLegendIcon.Rectangle;
            areaSeries.ItemsSource = areaSeriesDatas;
            chart1.Series.Add(areaSeries);

            splineSeries = new SplineSeries();
            splineSeries.Label = "Literacy";
            splineSeries.Color = GetColor(1);
            splineSeries.LegendIcon = ChartLegendIcon.Rectangle;
            splineSeries.YAxis = new NumericalAxis();
            splineSeries.YAxis.ShowMajorGridLines = false;
            splineSeries.YAxis.Title.Text = "Increase In Population";
            splineSeries.YAxis.OpposedPosition = true;
            splineSeries.ItemsSource = splineSeriesDatas;
            chart1.Series.Add(splineSeries);

            lineSeries = new LineSeries();
            lineSeries.Color = GetColor(2);
            lineSeries.Label = "Below Value";
            lineSeries.LegendIcon = ChartLegendIcon.Rectangle;
            lineSeries.ItemsSource = areaSeriesDatas;
            chart2.Series.Add(lineSeries);

            lineSeries1 = new LineSeries();
            lineSeries.Color = GetColor(3);
            lineSeries1.Label = "Above Value";
            lineSeries1.LegendIcon = ChartLegendIcon.Rectangle;
            lineSeries1.YAxis = new NumericalAxis();
            lineSeries1.YAxis.OpposedPosition = true;
            lineSeries1.YAxis.ShowMajorGridLines = false;
            lineSeries1.YAxis.Title.Text = "Above Poverty Line";
            lineSeries1.ItemsSource = lineSeriesDatas;
            chart2.Series.Add(lineSeries1);

            BoxView boxview;
            Label label;
            for (int i = 0; i < (chart1.Series.Count + chart2.Series.Count); i++)
            {
                boxview = new BoxView();
                boxview.HeightRequest = 12;
                boxview.VerticalOptions = LayoutOptions.CenterAndExpand;
                boxview.WidthRequest = 12;
                boxview.Color = GetColor(i);
                legendLayout.Children.Add(boxview);
                label = new Label();
                label.TextColor = Color.Black;
                if (i == 0)
                {
                    label.Text = areaSeries.Label;
                }
                else if (i == 1)
                {
                    label.Text = splineSeries.Label;
                }
                else if (i == 2)
                {
                    label.Text = lineSeries.Label;
                }
                else if (i == 3)
                {
                    label.Text = lineSeries1.Label;
                }
                legendLayout.Children.Add(label);
            }

            rootLayout.Children.Add(legendLayout);
            chart1.SetValue(Grid.RowProperty, 0);
            chart2.SetValue(Grid.RowProperty, 1);
            grid.Children.Add(chart1);
            grid.Children.Add(chart2);
            chartLayout.Children.Add(grid);
            rootLayout.Children.Add(chartLayout);
            Content = rootLayout;
        }
        Color GetColor(int index)
        {
            return customColors[index % 4];
        }
    }
}
